#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from math import trunc


class Celsius:
    """Provides conversion of Celsius to other temperature scales"""

    @staticmethod
    def to_fahrenheit(
        celsius: float | int, /, *, float_ret=True
    ) -> float | int:
        """
        Converts Celsius to Fahrenheit, returning a float by default.

        If the float_ret parameter is False, it returns an approximate int value
        (using the math's module trunc function).

        :param celsius: Celsius value to be converted
        :param float_ret: Optional, True by default to return floats
        :return: float or int
        """
        if float_ret:
            return float(celsius * 9 / 5 + 32)
        return trunc(celsius * 9 / 5 + 32)

    @staticmethod
    def to_delisle(celsius: float | int, /, *, float_ret=True) -> float | int:
        """
        Converts Celsius to Delisle, returning a float by default.

        If the float_ret parameter is False, it returns an approximate int value
        (using the math's module trunc function).

        :param celsius: Celsius value to be converted
        :param float_ret: Optional, True by default to return floats
        :return: float or int
        """
        if float_ret:
            return float((100 - celsius) * 3 / 2)
        return trunc((100 - celsius) * 3 / 2)

    @staticmethod
    def to_kelvin(celsius: float | int, /, *, float_ret=True) -> float | int:
        """
        Converts Celsius to Kelvin, returning a float by default.

        If the float_ret parameter is False, it returns an approximate int value
        (using the math's module trunc function).

        :param celsius: Celsius value to be converted
        :param float_ret: Optional, True by default to return floats
        :return: float or int
        """
        if float_ret:
            return float(celsius + 273.15)
        return trunc(celsius + 273.15)

    @staticmethod
    def to_newton(celsius: float | int, /, *, float_ret=True) -> float | int:
        """
        Converts Celsius to Newton, returning a float by default.

        If the float_ret parameter is False, it returns an approximate int value
        (using the math's module trunc function).

        :param celsius: Celsius value to be converted
        :param float_ret: Optional, True by default to return floats
        :return: float or int
        """
        if float_ret:
            return float(celsius * 33 / 100)
        return trunc(celsius * 33 / 100)

    @staticmethod
    def to_rankine(celsius: float | int, /, *, float_ret=True) -> float | int:
        """
        Converts Celsius to Rankine, returning a float by default.

        If the float_ret parameter is False, it returns an approximate int value
        (using the math's module trunc function).

        :param celsius: Celsius value to be converted
        :param float_ret: Optional, True by default to return floats
        :return: float or int
        """
        if float_ret:
            return float(celsius * 9 / 5 + 491.67)
        return trunc(celsius * 9 / 5 + 491.67)

    @staticmethod
    def to_reaumur(celsius: float | int, /, *, float_ret=True) -> float | int:
        """
        Converts Celsius to Réaumur, returning a float by default.

        If the float_ret parameter is False, it returns an approximate int value
        (using the math's module trunc function).

        :param celsius: Celsius value to be converted
        :param float_ret: Optional, True by default to return floats
        :return: float or int
        """
        if float_ret:
            return float(celsius * 4 / 5)
        return trunc(celsius * 4 / 5)

    @staticmethod
    def to_romer(celsius: float | int, /, *, float_ret=True) -> float | int:
        """
        Converts Celsius to Rømer, returning a float by default.

        If the float_ret parameter is False, it returns an approximate int value
        (using the math's module trunc function).

        :param celsius: Celsius value to be converted
        :param float_ret: Optional, True by default to return floats
        :return: float or int
        """
        if float_ret:
            return float(celsius * 21 / 40 + 7.5)
        return trunc(celsius * 21 / 40 + 7.5)


class Fahrenheit:
    """Provides conversion of Fahrenheit to other temperature scales"""

    @staticmethod
    def to_celsius(
        fahrenheit: float | int, /, *, float_ret=True
    ) -> float | int:
        """
        Converts Fahrenheit to Celsius, returning a float by default.

        If the float_ret parameter is False, it returns an approximate int value
        (using the math's module trunc function).

        :param fahrenheit: Fahrenheit value to be converted
        :param float_ret: Optional, True by default to return floats
        :return: float or int
        """
        if float_ret:
            return float((fahrenheit - 32) * 5 / 9)
        return trunc((fahrenheit - 32) * 5 / 9)

    @staticmethod
    def to_delisle(
        fahrenheit: float | int, /, *, float_ret=True
    ) -> float | int:
        """
        Converts Fahrenheit to Delisle, returning a float by default.

        If the float_ret parameter is False, it returns an approximate int value
        (using the math's module trunc function).

        :param fahrenheit: Fahrenheit value to be converted
        :param float_ret: Optional, True by default to return floats
        :return: float or int
        """
        if float_ret:
            return float((212 - fahrenheit) * 5 / 6)
        return trunc((212 - fahrenheit) * 5 / 6)

    @staticmethod
    def to_kelvin(
        fahrenheit: float | int, /, *, float_ret=True
    ) -> float | int:
        """
        Converts Fahrenheit to Kelvin, returning a float by default.

        If the float_ret parameter is False, it returns an approximate int value
        (using the math's module trunc function).

        :param fahrenheit: Fahrenheit value to be converted
        :param float_ret: Optional, True by default to return floats
        :return: float or int
        """
        if float_ret:
            return float((fahrenheit + 459.67) * 5 / 9)
        return trunc((fahrenheit + 459.67) * 5 / 9)

    @staticmethod
    def to_newton(
        fahrenheit: float | int, /, *, float_ret=True
    ) -> float | int:
        """
        Converts Fahrenheit to Newton, returning a float by default.

        If the float_ret parameter is False, it returns an approximate int value
        (using the math's module trunc function).

        :param fahrenheit: Fahrenheit value to be converted
        :param float_ret: Optional, True by default to return floats
        :return: float or int
        """
        if float_ret:
            return float((fahrenheit - 32) * 11 / 60)
        return trunc((fahrenheit - 32) * 11 / 60)

    @staticmethod
    def to_rankine(
        fahrenheit: float | int, /, *, float_ret=True
    ) -> float | int:
        """
        Converts Fahrenheit to Rankine, returning a float by default.

        If the float_ret parameter is False, it returns an approximate int value
        (using the math's module trunc function).

        :param fahrenheit: Fahrenheit value to be converted
        :param float_ret: Optional, True by default to return floats
        :return: float or int
        """
        if float_ret:
            return float(fahrenheit + 459.67)
        return trunc(fahrenheit + 459.67)

    @staticmethod
    def to_reaumur(
        fahrenheit: float | int, /, *, float_ret=True
    ) -> float | int:
        """
        Converts Fahrenheit to Réaumur, returning a float by default.

        If the float_ret parameter is False, it returns an approximate int value
        (using the math's module trunc function).

        :param fahrenheit: Fahrenheit value to be converted
        :param float_ret: Optional, True by default to return floats
        :return: float or int
        """
        if float_ret:
            return float((fahrenheit - 32) * 4 / 9)
        return trunc((fahrenheit - 32) * 4 / 9)

    @staticmethod
    def to_romer(fahrenheit: float | int, /, *, float_ret=True) -> float | int:
        """
        Converts Fahrenheit to Rømer, returning a float by default.

        If the float_ret parameter is False, it returns an approximate int value
        (using the math's module trunc function).

        :param fahrenheit: Fahrenheit value to be converted
        :param float_ret: Optional, True by default to return floats
        :return: float or int
        """
        if float_ret:
            return float((fahrenheit - 32) * (7 / 24) + 7.5)
        return trunc((fahrenheit - 32) * (7 / 24) + 7.5)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['totemp']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'totemp',
    'version': '0.3.0',
    'description': 'Temperature Converter',
    'long_description': '# ToTemp\n<div style="display: inline-block">\n  <img src="https://shields.io/pypi/v/totemp"  alt="package version"/>\n  <img src="https://img.shields.io/pypi/l/totemp.svg"  alt="license"/>\n</div>\n\n**ToTemp** is a temperature conversion package between Celcius, Delisle, Fahrenheit, Kelvin, Rankine, Reaumur, Newton and Romer\n\n## Usage\n\nFirst of all, install the package:\n\n```\npip install totemp\n```\n\nor, to have an example in poetry environments:\n\n```\npoetry add --group dev totemp\n```\n\nThen, just use it:\n\n> In these examples, you can observe the methods working with both\nClasses available in the package\n\n````python\n# Import Celcius class\nfrom totemp import Celsius\n\ntemperature = Celsius.to_fahrenheit(35)\nprint(temperature)  # 95.0 -> float\n\ntemperature = Celsius.to_fahrenheit(35, float_ret=False)\nprint(temperature)  # 95 -> int\n````\n````python\n# Import Fahrenheit class\nfrom totemp import Fahrenheit\n\ntemperature = Fahrenheit.to_newton(18.746)\nprint(temperature)  # -2.4299000000000004 -> float\n\ntemperature = Fahrenheit.to_newton(18.746, float_ret=False)\nprint(temperature)  # -2 -> int\n````\n````python\n# Import all classes (not recommended)\nfrom totemp import *\n\ntemperature = Celsius.to_delisle(345.797)\nprint(temperature)  # -368.69550000000004 -> float\n\ntemperature = Celsius.to_delisle(345.797, float_ret=False)\nprint(temperature)  # -368 -> int\n\ntemperature = Fahrenheit.to_rankine(500)\nprint(temperature)  # 959.6700000000001 -> float\n\ntemperature = Fahrenheit.to_rankine(500, float_ret=False)\nprint(temperature)  # 959 -> int\n````\n\nNote that **all returns are *float values*** if you dont specify "float_ret"\nparameter as False, which is True by default and that **applies to all methods**.\n\nAll methods have two parameters, the **value** (which is positional-only)\nand the **return type** (which is <float_ret>, that is by default True to return float\nvalues and keyword-only)\n\n## Package Versions\n\n---\n\n- _0.1.0_:\n  - Yanked, not functional;\n- _0.2.0_:\n  - Functional;\n  - Can convert Celsius to Delisle, Fahrenheit, Kelvin, Newton, Rankine, Réaumur and Rømer.\n\n\n- **0.3.0**:\n  - Changed methods implementations and adds Fahrenheit conversions;\n    - <scale_value> parameter is now positional-only;\n    - Adds new paramater -> float_ret -> Float Return (True by default, keyword-only);\n    - Celsius class methods were updated and enhanced;\n    - Can now convert Fahrenheit to Celsius, Delisle, Kelvin, Newton, Rankine, Réaumur and Rømer.\n\n---\n\n## License\n\nFor more information, check LICENSE file.\n',
    'author': 'Edson Pimenta',
    'author_email': 'edson.tibo@gmail.com',
    'maintainer': 'Edson Pimenta',
    'maintainer_email': 'edson.tibo@gmail.com',
    'url': 'https://github.com/eddyyxxyy/ToTemp',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from .temperature_types import Celsius, Fahrenheit

__author__ = 'Edson Pimenta and Dávilos Tavares'
__credits__ = ['Edson Pimenta', 'Dávilos Tavares']
__license__ = 'GPL-3.0'
__version__ = '0.3.0'
__maintainer__ = [
    'Edson Pimenta <edson.tibo@gmail.com>',
    'Dávilos Tavares <daviloscostagg@hotmail.com>',
]
__status__ = 'Development'
__all__ = ['Celsius', 'Fahrenheit']
